// Persistence of Vision Ray Tracer Scene Description File
// File: output.pov
// Vers: 3.6
// Desc: [Projet PovRAY] UDM-UQAM
// Date: Hiver 2003
//	 Summer 2008
// Auth: Processing.org [exported by superCAD]
// Mail: gll@spacekit.ca

#debug "\n\n"

#debug "                                                o        \n"
#debug "             oooo               oooo     oo    oo        \n"
#debug "            ooooooo   oooo    ooooooo     oo  oo         \n"
#debug "           oo   oooo ooooooo oooo  ooo     ooooo         \n"
#debug "           oo    oooooo  ooooooo    oo      oooo         \n"
#debug "           ooo   ooooo     oooooo  ooo      ooooo        \n"
#debug "            ooooooooooo   ooooooooooo      oo  oooo      \n"
#debug "              oooooo oooooooo  oooo    o   oo    oo      \n"
#debug "                 ooo   oooo                              \n"
#debug "  --( Guillaume  ooo  LaBelle )--       anar.ch          \n"
#debug "          oo     oo                                      \n"
#debug "          ooo   ooo                                      \n"
#debug "          oooooooo                                       \n"
#debug "            oooo                                         \n"

#debug "\n\n"

#debug concat( "\n--------------------------------------------------------\n",
               "Clk-(",str(clock,0, 3),"/",str(final_clock,0, 3),")-\n",
               "Frm-(",str(frame_number,0, 3),"/",str(final_frame,0, 3),")-\n",
               "--------------------------------------------------------\n\n")



// [HISTORY]

// V0.00a
// Début du Projet



//  ------------------------------------------------------------      
//  ------------------------------------------------------------
//     --( PréPROCESSOR )--
//  ------------------------------------------------------------

//--------------------------------------------------------------------------
#version 3.5;
//global_settings {  assumed_gamma 1.0 }
//--------------------------------------------------------------------------

#include "colors.inc"
#include "textures.inc"
#include "glass.inc"
#include "metals.inc"
#include "golds.inc"
#include "stones.inc"
#include "woods.inc"
#include "shapes.inc"
#include "shapes2.inc"
#include "functions.inc"

#declare Radiosity=on;

global_settings {
  assumed_gamma 1
  //max_trace_level 25
  #if (Radiosity)   
  assumed_gamma 1
    radiosity {
      pretrace_start 0.08           // start pretrace at this size
      pretrace_end   0.04           // end pretrace at this size
      count 235                      // higher -> higher quality (1..1600) [35]
      nearest_count 10               // higher -> higher quality (1..10) [5]
      error_bound 1.0               // higher -> smoother, less accurate [1.8]
      recursion_limit 1             // how much interreflections are calculated (1..5+) [3]
      low_error_factor .5           // reduce error_bound during last pretrace step
      gray_threshold 0.0            // increase for weakening colors (0..1) [0]
      minimum_reuse 0.0015           // reuse of old radiosity samples [0.015]
      brightness 0.30                  // brightness of radiosity effects (0..1) [1]

      adc_bailout 0.01/2
      //normal on                   // take surface normals into account [off]
      //media on                    // take media into account [off]
      //save_file "file_name"       // save radiosity data
      //load_file "file_name"       // load saved radiosity data
      //always_sample off           // turn sampling in final trace off [on]
      //max_sample 1.0              // maximum brightness of samples
    }
  #end   
  
 /*radiosity {
brightness 2.2
count 300
error_bound 0.15
gray_threshold 0.0
low_error_factor 0.2
minimum_reuse 0.015
nearest_count 10
recursion_limit 5
#if (version>3.1)
adc_bailout 0.01
max_sample -1.0
media off
normal off
always_sample 1

pretrace_start 0.08
pretrace_end 0.01
#end
}
}*/
  
}  




//  ------------------------------------------------------------      
//  ------------------------------------------------------------
//     --( CAMÉRA )--
//  ------------------------------------------------------------

#declare Camera_0 = camera {perspective angle 75          // front view
                            location  <0.0 , 1.0 ,-3.0>
                            right     x*image_width/image_height
                            look_at   <0.0 , 0.4 , 0.0>}
#declare Camera_1 = camera {ultra_wide_angle angle 90       // diagonal view
                            location  <2.0 , 2.5 ,-3.0>
                            right     x*image_width/image_height  
                            rotate <0, 20, 0> // <dX, dY, dZ> (in degrees)

                            look_at   <0.0 , 1.0 , 0.0>}
#declare Camera_2 = camera {ultra_wide_angle angle 90      //right side view
                            location  <3.0 , 1.0 , 0.0>
                            right     x*image_width/image_height
                            look_at   <0.0 , 1.0 , 0.0>}
#declare Camera_3 = camera {ultra_wide_angle angle 90            // top view
                            location  <0.0 , 3.0 ,-0.001>
                            right     x*image_width/image_height
                            look_at   <0.0 , 1.0 , 0.0>}
camera{Camera_1}


//  ------------------------------------------------------------      
//  ------------------------------------------------------------
//     --( TEXTURES )--
//  ------------------------------------------------------------

#declare GrayCaro =        texture{ pigment{checker color rgb<1,1,1>*1.2 color rgb<0.25,0.15,0.1> scale <1,1,1>*2}
                                        //normal {bumps 0.75 scale 0.025}
                                        finish {ambient 0.1 diffuse 0.3}
                                        }

#declare GrayCaroR =        texture{ pigment{checker color rgb<1,1,1>*1.2 color rgb<0.25,0.15,0.1> scale <1,1,1>*2}
                                        //normal {bumps 0.05 scale 0.02}
                                        finish {ambient 0.1 diffuse 0.8 reflection { 0.2 }} // REFLEX-------(oo)
                                        }

#declare WhiteR =        texture{ pigment{color rgb<1,1,1>}
                                        //normal {bumps 0.05 scale 0.02}
                                        finish {ambient 0.1 diffuse 0.8 reflection { 0.2 }} // REFLEX-------(oo)
                                        }

#declare GrayCaroS =       texture{ pigment{checker color rgb<1,1,1>*1.2 color rgb<0.25,0.15,0.1> scale <1,1,1>*0.1}
                                        //normal {bumps 0.75 scale 0.025}
                                        finish {ambient 0.1 diffuse 0.8}
                                        }

#declare GrayNoise =       texture{ pigment{color rgb<0.7,0.7,0.7>}
	                                normal {bumps 0.75 scale 0.03}
                                        finish {ambient 0.1 diffuse 0.8}
                                        }



#declare BeigeC = pigment {color rgb<1,0.90,0.6>}
#declare BeigeLight = pigment{color rgb<1,0.95,0.8>}
#declare Brun = pigment{color  rgb<1,0.75,0.4>*0.3}
#declare BeigeCc = pigment {BeigeC}


#declare Beige =           texture{ pigment{BeigeCc}
                                        finish {ambient 0.1
                                                diffuse 0.9
                                                brilliance 0.5
                                                phong 0.5
                                                phong_size 60
                                                specular 0.5
                                                roughness 0.05
                                                reflection { 0.1 }
                                                }
                                        }
// Beige LOWRes
#declare BeigeLw =           texture{ pigment{BeigeCc}
                                        finish {ambient 0.1
                                                diffuse 0.9
                                                //brilliance 0.5
                                                phong 0.3
                                                phong_size 3
                                                //specular 0.5
                                                //roughness 0.05
                                                //reflection { 0.1 }
                                                }
                                        }
// Beige LOW DARK
#declare BeigeLwD =           texture{ pigment{Brun}
                                        finish {ambient 0.1
                                                diffuse 0.9
                                                //brilliance 0.5
                                                phong 0.3
                                                phong_size 3
                                                //specular 0.5
                                                //roughness 0.05
                                                //reflection { 0.1 }
                                                }
                                        }



#declare BeigeT =            texture{ pigment{color rgbf<1,0.95,0.8,0.7>}
                                        finish {ambient 0.1
                                                diffuse 0.5
                                                brilliance 10
                                                //phong 0.3
                                                //phong_size 3
                                                specular 0.7
                                                roughness 0.1
                                                //reflection { 0.1 }
                                                }
                                        }


#declare RedT =            texture{ pigment{color rgbf<1,0.5,0.1,0.5>}
                                        finish {ambient 1
                                                diffuse 0.5
                                                //brilliance 0.5
                                                //phong 0.3
                                                //phong_size 3
                                                specular 0.5
                                                roughness 0.02
                                                //reflection { 0.1 }
                                                }
                                        }
                                                       
                                                       
                                                       
#declare DefTex = texture{      
  // texture component
  pigment {
    color rgbf <0.8,0.8,0.8,0.2>     // solid color pigment
    /*
    agate                       // patterned pigment
    color_map {
      [0.0 color Green ]
      [1.0 color Blue ]
    } */
  }

                       
// control an object's surface finish
  finish {
    ambient 0.1          // ambient surface reflection color [0.1]
    // (---diffuse lighting---)
    diffuse 1          // amount [0.6]
    brilliance 1.0       // tightness of diffuse illumination [1.0]
    // (---phong highlight---)
    phong 0.6          // amount [0.0]
    phong_size 40      // (1.0..250+) (dull->highly polished) [40]
    // (---specular highlight---)
    //specular 0.5       // amount [0.0]
    //roughness 0.05     // (~1.0..0.0005) (dull->highly polished) [0.05]
    // (---phong and specular---)
    //metallic [Amount]  // give highlight color of surface
    // (---reflection---)
    
    reflection {
      0.1                      // minimal reflection value (for variable reflection)
      //1.0                        // reflection amount (maximum for variable reflection)
      //fresnel on               // realistic variable reflection
      //falloff 1.0              // falloff exponent for variable reflection
      //exponent 1.0             // influence surface reflection characteristic
      //metallic 1.0             // tint reflection in surface color
    }
    //conserve_energy            // more realistic
    // (---others---)
    //crand 0.2                  // randomly speckle the surface [0.0]
                 /*
    irid {               // Iridescence (Newton's thin film interference)
      0.25               // intensity
      //thickness 0.0    // film's thickness [0.0]
      turbulence 0.3   // film's thickness turbulence
    }              */
  } // finish

}                                                       



//  ------------------------------------------------------------      
//  ------------------------------------------------------------
//     --( ÉCLAIRAGES ET ENVIRONNEMENT )--
//  ------------------------------------------------------------

// --( SOLEIL )--    

   /*      
light_source{<1500,2500,-2500> color rgb <1,0.5,0>
  fade_distance 1500
  fade_power 2
}       
             
light_source{<-2500,2500,1500> color rgb <0,0.5,1>
  fade_distance 1500
  fade_power 2
}        */          


     // An area light (creates soft shadows)
// WARNING: This special light can significantly slow down rendering times!
light_source {
  0*x                 // light's position (translated below)
  color rgb <0.9,0.8,0.7>*1.5       // light's color
  area_light
  <800, 0, 0> <0, 0, 800> // lights spread out across this distance (x * z)
  4, 4                // total number of lights in grid (4x*4z = 16 lights)
  adaptive 0          // 0,1,2,3...
  jitter              // adds random softening of light
  circular            // make the shape of the light circular
  orient              // orient light
  translate <1500,2500,-2500>   // <x y z> position of light   
  
  fade_distance 2000
  fade_power 2
}
 
 
     // An area light (creates soft shadows)
// WARNING: This special light can significantly slow down rendering times!
light_source {
  0*x                 // light's position (translated below)
  color rgb <0.7,0.8,0.9>*1.5       // light's color
  area_light
  <0, 0, 800> <0, 800, 0> // lights spread out across this distance (x * z)
  4, 4                // total number of lights in grid (4x*4z = 16 lights)
  adaptive 0          // 0,1,2,3...
  jitter              // adds random softening of light
  circular            // make the shape of the light circular
  orient              // orient light
  translate <-2500,2500,1500>   // <x y z> position of light  
  
  // light_source { ...
  // put this inside a light_source to add light fading
  fade_distance 2000
  fade_power 2

} 



// --( CIEL )--
plane{<0,1,0>,1 hollow  
       texture{ pigment{ bozo turbulence 0.076
                         color_map { [0.5 rgb <0.70, 0.70, 0.7>]
                                     [0.6 rgb <0.75,0.75,0.75>]
                                     [1.0 rgb <0.85,0.85,0.85>]}
                       }
                finish {ambient 1 diffuse 0} }      
       scale 10000}
                            
                            
                            
                            
// --( FOG )--
fog{fog_type   2
    distance   50
    color      White
    fog_offset 0.1
    fog_alt    2.0
    turbulence 0.8}

// --( SOL )--
#declare Plane_1 = plane{ <0,1,0>, 0 
       texture{ GrayCaroR }
     }

#declare Plane_0 = plane { <0,1,0>, 0 
        texture{ GrayNoise }
      }

#declare Plane_2 = plane { <0,1,0>, 0 
        texture{ WhiteR }
      }


Plane_2




//  ------------------------------------------------------------      
//  ------------------------------------------------------------
//     --( ÉCLAIRAGES ET ENVIRONNEMENT )--
//  ------------------------------------------------------------

#declare NODE = 1;  
#declare CylRad = 0.3;



////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////    


