#!/bin/bash
# ANAR+ BCVTB simulation script


################
# usage function

usage()
{
cat << EOF
usage: $0 options

This is the ANAR+ EnergyPlus simulation script 

OPTIONS:
	-h	
		Show this message
	-s  
   		BCVTB E+ simulation   	 
	-d  
   		BCVTB E+/dymola simulation   	 
	-f filename      
   		specifies output filename
   	-p 
   		plot already computed results	
EOF
}

#################
# option parsing

eplusflag=
eplusDymolaflag=
plotflag=
filename="out"
while getopts 'sf:dp' OPTION
do
	echo $OPTION $OPTARG
	case $OPTION in
	s)	eplusflag=1
	    plotflag=1
			;;
	d)	eplusDymolaflag=1
	    plotflag=1
			;;
	f)	filename="$OPTARG"
			;;
	p)	plotflag=1
			;;
	h)	usage
			exit
			;;
	?)	usage
			exit 2
			;;
	esac
done

# rewind the option counter to reuse the flags
shift $(($OPTIND - 1))
printf "Remaining arguments are: %s\n" "$*"


# level to lessen priority to leave processor time to applet realtime 
level="0"

#######################
# environment variables

# in case gnuplot is located there
export PATH="/usr/local/bin:$PATH"

export ENERGYPLUS_DIR="/usr/local/EnergyPlus"

bcvtbHome=BCVTBHome


##############
# simulation

if [ "$eplusflag" ]
then
	# note that parameters can now be used as normal since $OPTIND rewinded above
	# $1 = simulation directory
	# $2 = interactive flag
	if [ -z "$2" ]; then 
		echo BCVTB EnergyPlus simulation usage: bcvtb.sh -s -f filename dir interactive
		exit
	fi

	# move to simulation dir
    echo "simulation directory"
	cd $1
	pwd
	
	interactive="$2"
	echo $interactive
	
	# calculation
	if [ $interactive -gt 0 ]
	then
#		nice -n $level java -jar ${bcvtbHome}/bin/BCVTB.jar -run -file system.xml
		nice -n $level java -jar ${bcvtbHome}/bin/BCVTB.jar  -file system.xml
	else
		nice -n $level java -jar ${bcvtbHome}/bin/BCVTB.jar -console -file system.xml
	fi
            
    # move in the Output folder
    cd Output
    pwd
    
#    while [ ! -f ${filename}.eso]
#    do 
#    	sleep .1
#    done
#    nice -n $level runreadvars ${filename}.eso
    
    # give some time for copying files   
    while [ ! -f ${filename}.csv ]
    do 
    	sleep .1
        while [ ! -f ${filename}Meter.csv ]
        do
        	sleep .1
        done	
    done
    sleep .3
    
    # edit .csv file (both main one and meter one) 
    # 1- only take every EnergyPlusTimeStep line 
    # 2- replace '  ' (double space) with '-' [comply with gnuplot time format]
    # 3- replace ',' with ' ' [from .csv to gnuplot space format]
	sed -n '1~EnergyPlusTimeStepp' ${filename}.csv | sed -e '1d' -e 's/  /-/g' -e 's/,/ /g' > ../${filename}.dat
	sed -n '1~EnergyPlusTimeStepp' ${filename}Meter.csv | sed -e '1d' -e 's/  /-/g' -e 's/,/ /g' > ../${filename}Meter.dat

    # copy data file in $1 folder
#    cp ./${filename}.dat ../${filename}.dat
#    cp ./${filename}Meter.dat ../${filename}Meter.dat
	
	# copy error file in $1 folder
    cp ./${filename}.err ../${filename}ERRORS.txt

	# display is done in next option so come back on sketch folder
	cd ../../
	pwd	
fi


if [ "$eplusDymolaflag" ]
then
	# note that parameters can now be used as normal since $OPTIND rewinded above
	# $1 = simulation directory
	if [ -z "$1" ]; then 
		echo BCVTB EnergyPlus simulation usage: bcvtb.sh -s -f filename dir
		exit
	fi

	# move to simulation dir
    echo "simulation directory"
	cd $1
	pwd
	
	# calculation
	nice -n $level java -jar ${bcvtbHome}/bin/BCVTB.jar -console -file system.xml
    
    # move in the Output folder
    cd Output
    pwd
    
    # edit .csv file (both main one and meter one) 
    # 1- strip first line []
    # 2- replace ',' with ' ' [from .csv to gnuplot space format]
    # 3- replace '  ' (double space) with '-' [comply with gnuplot time format]
	sed '1d' ${filename}.csv | sed 's/,/ /g' | sed 's/  /-/g' > ../${filename}.dat
	sed '1d' ${filename}Meter.csv | sed 's/,/ /g' | sed 's/  /-/g' > ../${filename}Meter.dat

    # copy data file in $1 folder
#    cp ./${filename}.dat ../${filename}.dat
#    cp ./${filename}Meter.dat ../${filename}Meter.dat
	
	# copy error file in $1 folder
    cp ./${filename}.err ../${filename}ERRORS.txt

	# display is done in next option so come back on sketch folder
	cd ../../
	pwd	
fi


# fall back on plotting if simulation run

if [ "$plotflag" ]
then
	# note that parameters can now be used as normal since $OPTIND rewinded above
	# $1 = simulation directory
	if [ -z "$1" ]; then 
		echo energyPlus simulation usage: energyPlus.sh -s -f filename dir
		exit
	fi

	# move to simulation dir
	cd $1
	pwd

	# display the graph(s) using gnuplot
#	gnuplot -persist bcvtb.plt
	gnuplot bcvtb.plt
	
fi

exit