#!/bin/bash
# ANAR+ EnergyPlus simulation script


################
# usage function

usage()
{
cat << EOF
usage: $0 options

This is the ANAR+ EnergyPlus simulation script 

OPTIONS:
	-h	
		Show this message
	-s  
   		EnergyPlus simulation   	 
	-f filename      
   		specifies output filename
    -c climatefile
        specifies climate file (must be priorly installed for E+)
   	-p 
   		plot already computed results, specify if persistent or not	
EOF
}

#################
# option parsing

simflag=
plotflag=
persistflag=
filename="out"
# california uber alles
climate="USA_CA_San.Francisco.Intl.AP.724940_TMY3" 
while getopts 'sf:c:p:' OPTION
do
	echo $OPTION $OPTARG
	case $OPTION in
	s)	simflag=1
			;;
	f)	filename="$OPTARG"
			;;
	c)	climate="$OPTARG"
			;;
	p)	persistflag="$OPTARG"
		plotflag=1
			;;
	h)	usage
			exit
			;;
	?)	usage
			exit 2
			;;
	esac
done

# rewind the option counter to reuse the flags
shift $(($OPTIND - 1))
printf "Remaining arguments are: %s\n" "$*"


# level to lessen priority to leave processor time to applet realtime 
level="12"

#######################
# environment variables

# in case gnuplot is located there
export PATH="/usr/local/bin:$PATH"

# include root folder for climate file
# NOT FUNCTIONAL DUE TO E+ BUG 
export ENERGYPLUS_WEATHER=""EnergyPlusSketchPath""
echo "local weather path"
echo $ENERGYPLUS_WEATHER



##############
# simulation

if [ "$simflag" ]
then
	# note that parameters can now be used as normal since $OPTIND rewinded above
	# $1 = simulation directory
	if [ -z "$1" ]; then 
		echo energyPlus simulation usage: energyPlus.sh -s -f filename -c climatefile dir
		echo note: climate file must be priorly installed in EnergyPlus weather folder 
		exit
	fi

	# move to simulation dir
    echo "simulation directory"
	cd $1
	pwd
	
	# calculation
	nice -n $level runenergyplus ${filename}.imf $climate

    # move in the Output folder
    cd Output
    pwd
    
    # edit .csv file (both main one and meter one) 
    # 1- strip first line []
    # 2- replace '  ' (double space) with '-' [comply with gnuplot time format]
    # 3- replace ',' with ' ' [from .csv to gnuplot space format]
	sed '1d' ${filename}.csv | sed 's/  /-/g' | sed 's/,/ /g' > ../${filename}.dat
	sed '1d' ${filename}Meter.csv | sed 's/  /-/g' | sed 's/,/ /g' > ../${filename}Meter.dat

    # copy data file in $1 folder
#    cp ./${filename}.dat ../${filename}.dat
#    cp ./${filename}Meter.dat ../${filename}Meter.dat
	
	# copy error file in $1 folder
    cp ./${filename}.err ../${filename}ERRORS.txt

	# display is done in next option so come back on sketch folder
	cd ../../
	pwd	
fi

# fall back on plotting if simulation run

if [ "$plotflag" ]
then
	# note that parameters can now be used as normal since $OPTIND rewinded above
	# $1 = simulation directory
	if [ -z "$1" ]; then 
		echo energyPlus simulation usage: energyPlus.sh -s -f filename -c climatefile dir
		echo note: climate file must be priorly installed in EnergyPlus weather folder 
		exit
	fi

	# move to simulation dir
	cd $1
	pwd

	#printf "persistflag: %s\n" "$persistflag"
	
	# display the graph(s) using gnuplot
	if [ $persistflag -gt 0 ]; then
		echo plotting persistent
		gnuplot -persist energyPlus.plt
	else
		echo plotting non persistent
		gnuplot energyPlus.plt
	fi	
	
fi
exit